==> jruby-openssl_0.9.7.orig.tar.gz: jruby-openssl-0.9.7/src/main/java/org/jruby/ext/openssl/x509store/X509Aux.java <==
/***** BEGIN LICENSE BLOCK *****
 * Version: EPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Eclipse Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/epl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Copyright (C) 2006 Ola Bini <ola@ologix.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the EPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the EPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/
package org.jruby.ext.openssl.x509store;

import java.util.List;
import java.util.ArrayList;
import org.bouncycastle.asn1.ASN1Primitive;

/**
 * @author <a href="mailto:ola.bini@ki.se">Ola Bini</a>
 */
final class X509Aux {

    public String alias; /* "friendly name" */
    public byte[] keyid; /* key id of private key */

    final List<String> trust = new ArrayList<String>(); // String of OID's /* trusted uses */
    final List<String> reject = new ArrayList<String>(); // String of OID's /* rejected uses */
    List<ASN1Primitive> other = new ArrayList<ASN1Primitive>(); /* String of OID's of sigAlgs, other unspecified info */
    
}// X509_AUX

==> jruby-openssl_0.9.11.orig.tar.gz: jruby-openssl-0.9.11/src/main/java/org/jruby/ext/openssl/x509store/X509Aux.java <==
/***** BEGIN LICENSE BLOCK *****
 * Version: EPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Eclipse Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/epl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Copyright (C) 2006 Ola Bini <ola@ologix.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the EPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the EPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/
package org.jruby.ext.openssl.x509store;

import java.util.List;

import org.bouncycastle.asn1.ASN1Primitive;

/**
 * @author <a href="mailto:ola.bini@ki.se">Ola Bini</a>
 */
final class X509Aux {

    final String alias; /* "friendly name" */
    final byte[] keyid; /* key id of private key */

    final List<String> trust; // String of OID's /* trusted uses */
    final List<String> reject; // String of OID's /* rejected uses */
    final List<ASN1Primitive> other; /* String of OID's of sigAlgs, other unspecified info */

    X509Aux(final String alias, final byte[] keyid,
        final List<String> trust,
        final List<String> reject,
        final List<ASN1Primitive> other) {
        this.alias = alias;
        this.keyid = keyid;
        this.trust = trust;
        this.reject = reject;
        this.other = other;
    }

}// X509_AUX
